@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use DateTime::Format::RFC3339;
-use Params::ValidationCompiler qw( compile );
+use Params::ValidationCompiler qw( validation_for );
 use Scalar::Util qw( blessed );
 use WebService::PivotalTracker::Client;
 use WebService::PivotalTracker::Me;
@@ -62,7 +62,7 @@ sub projects {
 }
 
 {
-    my $check = compile(
+    my $check = validation_for(
         params => {
             project_id => { type => PositiveInt },
             filter     => {
@@ -93,9 +93,9 @@ sub projects {
 }
 
 {
-    my $check = compile(
+    my $check = validation_for(
         params => {
-            story_id => PositiveInt,
+            story_id => { type => PositiveInt },
         }
     );
 
@@ -113,9 +113,9 @@ sub projects {
 }
 
 {
-    my $check = compile(
+    my $check = validation_for(
         params => {
-            project_id => PositiveInt,
+            project_id => { type => PositiveInt },
             label      => {
                 type     => NonEmptyStr,
                 optional => 1
@@ -188,7 +188,7 @@ sub projects {
         },
     );
 
-    my $check = compile(
+    my $check = validation_for(
         params => \%params,
     );
 
@@ -252,13 +252,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::PivotalTracker - Perl library for the Pivotal Tracker REST API
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -279,13 +281,34 @@ B<This is very alpha (and as of yet mostly undocumented) software>.
 This module provides a Perl interface to the L<Pivotal
 Tracker|https://www.pivotaltracker.com/> REST API.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/WebService-PivotalTracker/issues>.
+
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module, please
+consider making a "donation" to me via PayPal. I spend a lot of free time
+creating free software, and would appreciate any support you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order for me
+to continue working on this particular software. I will continue to do so,
+inasmuch as I have in the past, for as long as it interests me.
+
+Similarly, a donation made in this way will probably not make me work on this
+software much more, unless I get so many donations that I can consider working
+on free software full time (let's all have a chuckle at that together).
+
+To donate, log into PayPal and send money to autarch@urth.org, or use the
+button at L<http://www.urth.org/~autarch/fs-donation.html>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Dave Rolsky Greg Oschwald
+=for stopwords Dave Rolsky Florian Ragwitz Greg Oschwald
 
 =over 4
 
@@ -295,6 +318,10 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =item *
 
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
 Greg Oschwald <goschwald@maxmind.com>
 
 =back
